@@ -1,22 +1,12 @@
-/******************************** LICENSE ********************************
-
-
- Copyright 2007 European Centre for Medium-Range Weather Forecasts (ECMWF)
- 
- Licensed under the Apache License, Version 2.0 (the "License"); 
- you may not use this file except in compliance with the License. 
- You may obtain a copy of the License at 
- 
- 	http://www.apache.org/licenses/LICENSE-2.0
- 
- Unless required by applicable law or agreedto in writing, software
- distributed under the License is distributed on an "AS IS" BASIS, 
- WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied. 
- See the License for the specific language governing permissions and 
- limitations under the License.
-
-
- ******************************** LICENSE ********************************/
+/*
+ * (C) Copyright 1996-2016 ECMWF.
+ * 
+ * This software is licensed under the terms of the Apache Licence Version 2.0
+ * which can be obtained at http://www.apache.org/licenses/LICENSE-2.0. 
+ * In applying this licence, ECMWF does not waive the privileges and immunities 
+ * granted to it by virtue of its status as an intergovernmental organisation nor
+ * does it submit to any jurisdiction.
+ */
 
 /*! \file PolarStereographicProjection.cc
     \brief Implementation of PolarStereographicProjection.
@@ -172,11 +162,14 @@ void PolarStereographicProjection::init(double width, double height)
 	if ( !projection_ ) 
 		projection_ = new TePolarStereographic(TeDatum(), vertical_longitude_*TeCDR, 0., 0., "Meters", (hemisphere_ == NORTH) ? TeNORTH_HEM : TeSOUTH_HEM);
 	
+	
+
 	if ( magCompare(area_, "full") ) {
 		ymin_ = ( hemisphere_ == NORTH ) ? -20. : 20.;
 		ymax_ = ( hemisphere_ == NORTH ) ? -20. : 20.;
-		xmin_ = ( hemisphere_ == NORTH ) ? -45. : 45.;
-		xmax_ = ( hemisphere_ == NORTH ) ? 135. : -135.;
+		xmin_ = ( hemisphere_ == NORTH ) ? -45. + vertical_longitude_ : 45. + vertical_longitude_;
+		xmax_ = ( hemisphere_ == NORTH ) ? 135. + vertical_longitude_ : -135. + vertical_longitude_;
+		
 	}
 	else
 		magCompare(area_, "corners" ) ?  corners() : centre(width, height);
@@ -300,7 +293,7 @@ void PolarStereographicProjection::init(double width, double height)
 		PCEnveloppe_->push_back(PaperPoint(xpcmax_, ypcmin_));
 		PCEnveloppe_->push_back(PaperPoint(xpcmin_, ypcmin_));
 
-		boost::geometry::correct(PCEnveloppe_->polygon_);
+		//boost::geometry::correct(PCEnveloppe_->polygon_);
 
 
 		MagLog::dev() << " Projection definition-->[" << ymin_ << ", " << xmin_ << ", " << xmax_ << ", " << ymax_ << "]" << endl;
@@ -590,15 +583,20 @@ void PolarStereographicProjection::labels(const LabelPlotting& label, DrawingVis
 {
 	Text *text;
 	const vector<double>& latitudes = label.latitudes();
-	//const vector<double>& longitudes = label.longitudes();
+	const vector<double>& grid = label.longitudes();
 	vector<double> longitudes;
-	longitudes.push_back(0);
-	unsigned int flat = (unsigned int) std::max(1, (int) maground(latitudes.size()/4));
+	longitudes.push_back(vertical_longitude_);
+	for ( float i = 0; i < 360; i += 60.) {
+		if ( find(grid.begin(), grid.end(), i) != grid.end() || 
+			 find(grid.begin(), grid.end(), i-360) != grid.end() )
+			longitudes.push_back(vertical_longitude_+i);
+	}
+	
 	unsigned int flon = (unsigned int) std::max(1, (int) maground(longitudes.size()/4));
 
-	for (unsigned int lat = 0; lat < latitudes.size(); lat += flat)
+	for (unsigned int lat = 0; lat < latitudes.size(); lat++)
 	{  
-	    for (unsigned int lon = 0 ; lon < longitudes.size(); lon += flon)
+	    for (unsigned int lon = 0 ; lon < longitudes.size(); lon ++)
 	    { 	   
 	   	   UserPoint point(longitudes[lon],latitudes[lat]);
 	   	   PaperPoint xy = (*this)(point);
@@ -690,10 +688,12 @@ void PolarStereographicProjection::corners()
 	// For backwards compatibility!
 	if  ( min_longitude_ == -180 && max_longitude_ == 180 &&
 		   min_latitude_ == -90 && max_latitude_ == 90 ) {
+
+		
 		min_latitude_ = ( hemisphere_ == NORTH ) ? -20. : 20.;
 		max_latitude_ = ( hemisphere_ == NORTH ) ? -20. : 20.;
-		min_longitude_ = ( hemisphere_ == NORTH ) ? -45. : 45.;
-		max_longitude_ = ( hemisphere_ == NORTH ) ? 135. : -135.;
+		min_longitude_ = ( hemisphere_ == NORTH ) ? -45. + vertical_longitude_: 45.+ vertical_longitude_;
+		max_longitude_ = ( hemisphere_ == NORTH ) ? 135. + vertical_longitude_: -135.+ vertical_longitude_;
 	}
 
 	xmin_ = min_longitude_;
@@ -832,14 +832,19 @@ void PolarStereographicProjection::reprojectComponents(double& x, double& y, pai
 
 void PolarStereographicProjection::reprojectSpeedDirection(const PaperPoint& point, pair<double, double>& wind) const
 {
-	double a = 90 - (wind.second); 
-	const double x = 3.14/180.;
-	a *= x;
-	double xx =0, yy=0;
-	const double speed =wind.first; 
-	wind.first = speed-1 * cos(a);
-	wind.second = speed-1 * sin(a);
-	reprojectComponents(xx, yy, wind);
+
+	double x = point.x_;
+	double y =  point.y_;
+
+	double u = x + (  sin( wind.second*DEG_TO_RAD) );
+	double v = y + (  cos( wind.second*DEG_TO_RAD) );
+
+	fast_reproject(x, y);
+	fast_reproject(u, v);
+	
+	double rotation = atan2((u - x), (v - y));
+	
+	wind.second =   (rotation*RAD_TO_DEG);
 }
 
 void PolarStereographicProjection::coastSetting(map<string, string>& setting, double abswidth, double absheight) const
@@ -888,6 +893,7 @@ Polyline& PolarStereographicProjection::getPCBoundingBox() const
 	if ( PCEnveloppe_->empty() ) {
 		getUserBoundingBox();
 	}
+	cout << *PCEnveloppe_ << endl;
 	return *PCEnveloppe_;
 }
 
@@ -978,4 +984,3 @@ UserPoint PolarStereographicProjection::reference() const
 	UserPoint ll = ( hemisphere_ ==  NORTH ) ? UserPoint(0, 60) : UserPoint(0, -60);
 	return ll;
 }
-
