@@ -1,9 +1,9 @@
 /*
  * (C) Copyright 1996-2016 ECMWF.
- * 
+ *
  * This software is licensed under the terms of the Apache Licence Version 2.0
- * which can be obtained at http://www.apache.org/licenses/LICENSE-2.0. 
- * In applying this licence, ECMWF does not waive the privileges and immunities 
+ * which can be obtained at http://www.apache.org/licenses/LICENSE-2.0.
+ * In applying this licence, ECMWF does not waive the privileges and immunities
  * granted to it by virtue of its status as an intergovernmental organisation nor
  * does it submit to any jurisdiction.
  */
@@ -43,6 +43,7 @@ public:
 		methods_["max_latitude"] = &Epsg::maxlat;
 		methods_["method"] = &Epsg::method;
 		initMethods_["geos"] = &Epsg::geosinit;
+		initMethods_["tpers"] = &Epsg::tpersinit;
 	}
 	string name_;
 	string definition_;
@@ -79,16 +80,32 @@ public:
 	}
 
 	void geosinit(const Proj4Projection& from) {
-		
+
 		minlon_ = from.vertical_longitude_ - 80;
 		maxlon_ = from.vertical_longitude_ + 80;
 		minlat_ = -80;
 		maxlat_ = 80;
-		
+
 		ostringstream def;
 		def << "+proj=geos +h=42164000 +ellps=WGS84 +lon_0=" << from.vertical_longitude_;
-
+		
+		//def << "++proj=tpers    +ellps=WGS84 +h=5000000  +lat_0=20 +lon_0=-60 +x_0=0 +y_0=0 +azi=20 +tilt=0  +units=m";
 		definition_ = def.str();
+	}
+
+	void tpersinit(const Proj4Projection& from) {
+
+		
+		
+		ostringstream def;
+		
+		def << "+proj=tpers +ellps=WGS84 +h=" << from.projection_height_;
+		def << "  +lat_0=" << from.projection_view_latitude_;
+		def << " +lon_0=" << from.projection_view_longitude_ ;
+		def << " +x_0=0 +y_0=0 +azi=" << from.projection_azimuth_;
+		def << " +tilt=" << from.projection_tilt_ << "  +units=m";
+		definition_ = def.str();
+
 		
 	}
 
@@ -182,7 +199,6 @@ Proj4Projection::Proj4Projection(const string& definition) : definition_(definit
 						gridMaxLon_(-DBL_MAX),
 						gridMaxLat_(-DBL_MAX)
 {
-
 	//init();
 	EpsgConfig config;
 	config.init();
@@ -202,16 +218,16 @@ Proj4Projection::Proj4Projection(): gridMinLon_(DBL_MAX),
 /*!
   \brief Destructor
 */
-Proj4Projection::~Proj4Projection() 
-{	
+Proj4Projection::~Proj4Projection()
+{
 }
 
 void Proj4Projection::print(ostream& out) const
 {
     out << "Proj4Projection[";
     Proj4ProjectionAttributes::print(out);
-    out << "]"; 
-} 
+    out << "]";
+}
 
 Polyline& Proj4Projection::getPCBoundingBox() const
 {
@@ -223,13 +239,14 @@ Polyline& Proj4Projection::getUserBoundingBox() const
 	return *userEnveloppe_;
 }
 
-void Proj4Projection::init()  
+void Proj4Projection::init()
 {
 	MagLog::dev() << "Proj4Projection::init()" << *this << endl;
 
 	from_ = pj_init_plus("+proj=longlat +ellps=WGS84 +datum=WGS84");
 	projection_ = Epsg::find(*this);
 	to_    = pj_init_plus(projection_->definition());
+	
 	if ( !to_) {
 		MagLog::error() << pj_strerrno(pj_errno) << endl;
 		MagLog::error() << " proj4 error " << projection_->definition() << endl;
@@ -238,10 +255,9 @@ void Proj4Projection::init()
 
 
 	methods_["geos"] = &Proj4Projection::geos;
+	methods_["tpers"] = &Proj4Projection::geos;
 	methods_["conic"] = &Proj4Projection::conic;
 	methods_["simple"] = &Proj4Projection::simple;
-	
-	
 
 	map<string,  InitMethod >::iterator method = methods_.find(projection_->method_);
 	if ( method != methods_.end() )
@@ -249,13 +265,12 @@ void Proj4Projection::init()
 	else
 		simple();
 
-
 	helpers_["full"] = &Proj4Projection::full;
 	helpers_["corners"] = &Proj4Projection::corners;
 	helpers_["centre"] = &Proj4Projection::centre;
 	helpers_["projection"] = &Proj4Projection::projectionSimple;
 
-	if ( coordinates_system_ == "projection" ) 
+	if ( coordinates_system_ == "projection" )
 		setting_ = "projection";
 
 	map<string,  SettingHelper >::iterator helper = helpers_.find(lowerCase(setting_));
@@ -263,9 +278,8 @@ void Proj4Projection::init()
 	if ( helper != helpers_.end() )
 		(this->*helper->second)();
 	else {
-		MagLog::warning() << " Coud not fing method " << setting_ << " to set the geographical area"
+		MagLog::warning() << " Could not find method " << setting_ << " to set the geographical area"
 				<< "  Going back to default area" << endl;
-
 		full();
 	}
 
@@ -278,16 +292,50 @@ void Proj4Projection::init()
 void Proj4Projection::full()
 {
 	if ( projection_->method_ == "simple" ) {
-		if ( min_longitude_ != -180 )
+
+		if ( max_longitude_ != 180. ) {
+			if ( max_latitude_ == 90 )
+				max_latitude_ = projection_->maxlat_;
+			if ( min_latitude_ == -90 )
+				min_latitude_ = projection_->minlat_;
 			corners();
-		if ( max_longitude_ != 180. )
+			return;
+		}
+		if ( max_longitude_ == 180. ) {
+			projection_->maxlon_ = 180.;
+			if ( max_latitude_ == 90 )
+				max_latitude_ = projection_->maxlat_;
+			if ( min_latitude_ == -90 )
+				min_latitude_ = projection_->minlat_;
 			corners();
-		if ( min_latitude_ != -90 )
+			return;
+		}
+
+		if ( min_longitude_ != -180 ) {
+			// set projection default !
+			if ( max_latitude_ == 90 )
+				max_latitude_ = projection_->maxlat_;
+			if ( min_latitude_ == -90 )
+				min_latitude_ = projection_->minlat_;
 			corners();
-		if ( max_latitude_ != 90 )
+		}
+
+		if ( min_latitude_ != -90 ) {
+
+			if ( max_latitude_ == 90 )
+				max_latitude_ = projection_->maxlat_;
 			corners();
+			return;
+		}
+		if ( max_latitude_ != 90 ) {
+			if ( min_longitude_ == -180 )
+				min_longitude_ = projection_->minlon_;
+			if ( min_latitude_ == -90 )
+				min_latitude_ = projection_->minlat_;
+			corners();
+			return;
+		}
 	}
-	
 }
 
 void Proj4Projection::corners()
@@ -304,14 +352,17 @@ void Proj4Projection::corners()
 		Polyline box;
 		box.box(PaperPoint(min_pcx_, min_pcy_), PaperPoint(max_pcx_, max_pcy_));
 
-		vector<Polyline> newbox;
+		vector<Polyline*> newbox;
 		PCEnveloppe_->intersect(box, newbox);
 		if ( newbox.empty() ) {
 			MagLog::warning() << "Proj4 : the sub-area is not valid : use global view instead" << endl;
 		}
 		else {
-			PCEnveloppe_ = newbox.front().clone();
+			PCEnveloppe_ = newbox.front();
 		}
+		// Clear newbox 
+
+
 }
 
 void Proj4Projection::centre()
@@ -324,14 +375,10 @@ PaperPoint Proj4Projection::operator()(const UserPoint& point)  const
 		from_ = pj_init_plus("+proj=longlat +ellps=WGS84 +datum=WGS84");
 		projection_ = Epsg::find(*this);
 		to_    = pj_init_plus(projection_->definition());
+		
 	}
 	double x = point.x();
 	double y = point.y();
-	
-	
-	
-
-	
 
 	x *= DEG_TO_RAD;
 	y *= DEG_TO_RAD;
@@ -339,9 +386,13 @@ PaperPoint Proj4Projection::operator()(const UserPoint& point)  const
     int error = pj_transform(from_, to_, 1, 1, &x, &y, NULL);
     if ( error ) {
 		MagLog::debug() << pj_strerrno(error) << " for " << point << endl;
-		return PaperPoint(-1000000, -10000000);
+//		NON Valeurs trop faibles en EPSG:3857 par exemple !  --> Transformation::in(pp) == True !
+//		-> Avec ces valeurs, si grille globale, les barbules des poles sont tracées dans l'atlantique sud
+//		en formant une couronne centrée vers( 9°W, 66°35S)
+//		return PaperPoint(-1000000, -10000000);   .// En plus il manque 1 zero !
+		return PaperPoint(-1e10, -1e10);    // Devrait suffire pour que Transformation::in(pp) == False qqsoient from_ et to_
 	}
-	
+
 	return PaperPoint(x, y, point.value_, point.missing(), point.border(), 0, point.name());
 }
 
@@ -372,6 +423,19 @@ void Proj4Projection::setNewPCBox(double minx, double miny, double maxx, double
 
 void Proj4Projection::revert(const PaperPoint& xy, UserPoint& point)  const
 {
+	static bool first = true;
+	if ( first ) {
+
+		const_cast<Proj4Projection*>(this)->init();
+		first = false;
+	}
+	if ( PCEnveloppe_->within(xy) == false ) {
+				  point = UserPoint(-1000, -1000);
+
+			 return;
+	}
+
+
 	double x = xy.x();
 	double y = xy.y();
 
@@ -396,7 +460,7 @@ bool Proj4Projection::needShiftedCoastlines()  const
 	return false;
 }
 
-void Proj4Projection::aspectRatio(double& width, double& height)  
+void Proj4Projection::aspectRatio(double& width, double& height)
 {
 	MagLog::dev() << "Proj4Projection::aspectRatio(...) needs implementing." << endl;
 	Transformation::aspectRatio(width, height);
@@ -410,6 +474,7 @@ void Proj4Projection::add(double lon, double lat)
 	int error =  pj_transform(from_, to_, 1, 1, &x, &y, NULL );
 	userEnveloppe_->push_back(PaperPoint(lon, lat));
 	PCEnveloppe_->push_back(PaperPoint(x, y));
+
 	if ( x < min_pcx_ )  min_pcx_ = x;
 	if ( y < min_pcy_ )  min_pcy_ = y;
 	if ( x > max_pcx_ )  max_pcx_ = x;
@@ -423,35 +488,22 @@ void Proj4Projection::add(double lon, double lat)
 void Proj4Projection::conic()
 {
 	userEnveloppe_->clear();
-		PCEnveloppe_->clear();
+	PCEnveloppe_->clear();
 	min_pcx_ = DBL_MAX;
-		min_pcy_ = DBL_MAX;
-		max_pcx_ = -DBL_MAX;
-		max_pcy_ = -DBL_MAX;
-	/*
-	// left
-	for ( int lat = projection_->minlat_; lat <= projection_->maxlat_; lat++) {
-		add(projection_->minlon_, lat);
-	}
-	*/
+	min_pcy_ = DBL_MAX;
+	max_pcx_ = -DBL_MAX;
+	max_pcy_ = -DBL_MAX;
+	
 	// top
 	add( projection_->minlon_ - vertical_longitude_, projection_->maxlat_);
-	for ( int lon = projection_->minlon_; lon <= projection_->maxlon_; lon++) {
+	for ( float lon = projection_->minlon_; lon <= projection_->maxlon_; lon++) {
+		
 		add(lon, projection_->minlat_);
 	}
 	add( projection_->maxlon_, projection_->maxlat_);
 	PCEnveloppe_->correct();
 	userEnveloppe_->correct();
-	/*
-	// right
-	for ( int lat = projection_->maxlat_; lat >= projection_->minlat_; lat--) {
-		add(projection_->maxlon_, lat);
-	}
-	// bottom
-	for ( int lon = projection_->maxlon_; lon >= projection_->minlon_; lon--) {
-			add(lon, projection_->minlat_);
-		}
-	*/
+	
 }
 
 
@@ -473,34 +525,37 @@ void Proj4Projection::simple()
 
 void Proj4Projection::projectionSimple()
 {
-
 		min_pcx_ = min_longitude_;
 		min_pcy_ = min_latitude_;
 		max_pcx_ = max_longitude_;
 		max_pcy_ = max_latitude_;
 		pj_transform(to_, from_, 1, 1, &min_longitude_, &min_latitude_, NULL );
 		pj_transform(to_, from_, 1, 1, &max_longitude_, &max_latitude_, NULL );
-	
+
 		min_longitude_ *= RAD_TO_DEG;
 		min_latitude_ *= RAD_TO_DEG;
 		max_longitude_ *= RAD_TO_DEG;
+		if (max_longitude_ < 0 ) {
+			max_longitude_ +=360.;
+		}
+
 		max_latitude_ *= RAD_TO_DEG;
-	
+
+
 		Polyline box;
 		box.box(PaperPoint(min_pcx_, min_pcy_), PaperPoint(max_pcx_, max_pcy_));
 
-		vector<Polyline> newbox;
+		vector<Polyline*> newbox;
 		PCEnveloppe_->intersect(box, newbox);
 		if ( newbox.empty() ) {
 			MagLog::warning() << "Proj4 : the sub-area is not valid : use global view instead" << endl;
 		}
 		else {
-			PCEnveloppe_ = newbox.front().clone();
+			PCEnveloppe_ = newbox.front();
 		}
-		// reset 
+		// reset
 		setting_ = "corners";
 		coordinates_system_ = "latlon";
-	
 }
 
 
@@ -515,35 +570,55 @@ void Proj4Projection::geos()
 		max_pcx_ = -DBL_MAX;
 		max_pcy_ = -DBL_MAX;
 
-		PCEnveloppe_->correct();
-		userEnveloppe_->correct();
-
+		
 		map<double, vector<double> > helper;
 
 		for ( int lat = projection_->minlat_; lat <= projection_->maxlat_; lat++) {
 			helper.insert(make_pair(lat, vector<double>()));
+			
 			for ( int lon =  projection_->minlon_; lon <= projection_->maxlon_; lon++) {
 				double x = lon*DEG_TO_RAD;
 				double y = DEG_TO_RAD*lat;
 				int error =  pj_transform(from_, to_, 1, 1, &x, &y, NULL );
+				
 				if ( !error) {
 					helper[lat].push_back(lon);
 				}
 			}
 		}
+
+		
+		
+
 		// now we create the envelope...
-		for ( map<double, vector<double> >::iterator lat = helper.begin(); lat != helper.end(); ++lat) {
+		for ( map<double, vector<double> >::iterator lat = helper.begin() ; lat != helper.end(); ++lat) {
 			if ( lat->second.empty() )
 				continue;
+			
+			
 			add(lat->second.front(), lat->first);
+			//userEnveloppe_->push_back(PaperPoint(lat->second.front(), lat->first));
 
 		}
 		// now reverse!
+		
 		for ( map<double, vector<double> >::reverse_iterator lat = helper.rbegin(); lat != helper.rend(); ++lat) {
 			if ( lat->second.empty() )
 				continue;
+			
 			add(lat->second.back(), lat->first);
-			userEnveloppe_->push_back(PaperPoint(lat->second.back(), lat->first));
+			//userEnveloppe_->push_back(PaperPoint(lat->second.back(), lat->first));
+		}
+
+		map<double, vector<double> >::iterator last = helper.begin();
+		for ( last = helper.begin() ; last != helper.end(); ++last) {
+			if ( !last->second.empty() )
+				break;
+		}
+
+		for ( vector<double>::reverse_iterator lon = last->second.rbegin(); lon != last->second.rend(); ++lon) {
+			add(*lon, last->first);
+			//userEnveloppe_->push_back(PaperPoint(*lon, last->first));
 		}
 }
 
@@ -553,13 +628,17 @@ void Proj4Projection::boundingBox(double& xmin, double& ymin, double& xmax, doub
 {
 	if ( ! from_ ) {
 			from_ = pj_init_plus("+proj=longlat +ellps=WGS84 +datum=WGS84");
+			
 			projection_ = Epsg::find(definition_);
-			to_    = pj_init_plus(proj4_definition_.c_str());
+			to_    = pj_init_plus(projection_->definition());
 		}
+
 	ymin = gridMinLat_;
 	xmin = gridMinLon_-5;
 	ymax = gridMaxLat_;
 	xmax = gridMaxLon_+5;
+
+	
 }
 
 double Proj4Projection::getMinX()  const
@@ -582,22 +661,22 @@ double Proj4Projection::getMaxY()  const
 	return gridMaxLat_;
 }
 
-void Proj4Projection::setMinX(double x)  
+void Proj4Projection::setMinX(double x)
 {
 	min_longitude_ = x;
 }
 
-void Proj4Projection::setMinY(double y)  
+void Proj4Projection::setMinY(double y)
 {
 	min_latitude_ = y;
 }
 
-void Proj4Projection::setMaxX(double x)  
+void Proj4Projection::setMaxX(double x)
 {
 	max_longitude_ = x;
 }
 
-void Proj4Projection::setMaxY(double y)  
+void Proj4Projection::setMaxY(double y)
 {
 	max_latitude_ = y;
 }
@@ -627,14 +706,14 @@ void Proj4Projection::gridLongitudes(const GridPlotting& grid)  const
 {
 	Polyline boundaries;
 
-	for (Polyline::MagLine::const_iterator point = PCEnveloppe_->begin(); point != PCEnveloppe_->end(); ++point )
+	for (auto point = PCEnveloppe_->begin(); point != PCEnveloppe_->end(); ++point )
 	{
 		boundaries.push_back(*point);
 	}
 
 	grid.add(boundaries);
 
-	
+
 	vector<double> longitudes = grid.longitudes();
 
 
@@ -654,11 +733,13 @@ void Proj4Projection::gridLongitudes(const GridPlotting& grid)  const
 				if ( userEnveloppe_->within(p) )
 					poly.push_back((*this)(UserPoint(*lon,lat)));
 			}
-			if ( *lon == gridMinLon_ || *lon == gridMaxLon_) 
-				grid.addFrame(poly);
-			else 
+
+			
 				grid.add(poly);
+
 		}
+		grid.addFrame(*PCEnveloppe_);
+	
 }
 
 void Proj4Projection::gridLatitudes(const GridPlotting& grid)  const
@@ -667,6 +748,7 @@ void Proj4Projection::gridLatitudes(const GridPlotting& grid)  const
 
 	const double step = 0.5;
 	const vector<double>::const_iterator lat_end = latitudes.end();
+
 	for(vector<double>::const_iterator lat = latitudes.begin(); lat != lat_end; ++lat)
 	{
 
@@ -678,17 +760,20 @@ void Proj4Projection::gridLatitudes(const GridPlotting& grid)  const
 			if ( userEnveloppe_->within(p) )
 				poly.push_back((*this)(UserPoint(lon,*lat)));
 		}
-		if ( *lat == gridMinLat_ || *lat == gridMaxLat_) 
-				grid.addFrame(poly);
-			else 
-				grid.add(poly);
+		
+		
+		grid.add(poly);
 		
 	}
+
+	grid.addFrame(*PCEnveloppe_);
+	
+
 }
 
 void Proj4Projection::labels(const LabelPlotting& label, DrawingVisitor& visitor)  const
 {
-	if ( projection_->method_ == "simple" ) 
+	if ( projection_->method_ == "simple" )
 		return;
 	vector<double> pro4_longitudes;
 	pro4_longitudes.push_back(0);
@@ -728,9 +813,9 @@ void Proj4Projection::labels(const LabelPlotting& label, LeftAxisVisitor& visito
 
 		for (unsigned int lat = 0; lat < latitudes.size(); lat++ )
 		{
-			if ( latitudes[lat] < gridMinLat_) 
+			if ( latitudes[lat] < gridMinLat_)
 				continue;
-			if ( latitudes[lat] > gridMaxLat_) 
+			if ( latitudes[lat] > gridMaxLat_)
 				continue;
 			double lon = max_longitude_ - ((max_longitude_-min_longitude_)*.1);
 			UserPoint point(lon,latitudes[lat]);
@@ -758,9 +843,9 @@ void Proj4Projection::labels(const LabelPlotting& label, RightAxisVisitor& visit
 		const vector<double>& latitudes = label.latitudes();
 		for (unsigned int lat = 0; lat < latitudes.size(); lat++ )
 		{
-			if ( latitudes[lat] < gridMinLat_) 
+			if ( latitudes[lat] < gridMinLat_)
 				continue;
-			if ( latitudes[lat] > gridMaxLat_) 
+			if ( latitudes[lat] > gridMaxLat_)
 				continue;
 			double lon = min_longitude_ + ((max_longitude_-min_longitude_)*.1);
 			UserPoint point(lon,latitudes[lat]);
@@ -789,10 +874,10 @@ void Proj4Projection::labels(const LabelPlotting& label, BottomAxisVisitor& visi
 		const double lat = min_latitude_ + (max_latitude_-min_latitude_)*.8;
 		for (unsigned int lon = 0; lon < longitudes.size(); lon++ )
 		{
-			
-			if ( longitudes[lon] < gridMinLon_) 
+
+			if ( longitudes[lon] < gridMinLon_)
 				continue;
-			if ( longitudes[lon] > gridMaxLon_) 
+			if ( longitudes[lon] > gridMaxLon_)
 				continue;
 			UserPoint point(longitudes[lon],lat);
 			PaperPoint xy = (*this)(point);
@@ -800,7 +885,7 @@ void Proj4Projection::labels(const LabelPlotting& label, BottomAxisVisitor& visi
 			Text *text = new Text();
 			label.add(text);
 			text->setText(writeLongitude(point));
-			
+
 			text->push_back(xy);
 			text->setJustification(MCENTRE);
 			text->setVerticalAlign(MTOP);
@@ -907,9 +992,9 @@ void Proj4Projection::labels(const LabelPlotting& label, TopAxisVisitor& visitor
 		const double lat = min_latitude_ + (max_latitude_-min_latitude_)*.2;
 		for (unsigned int lon = 0; lon < longitudes.size(); lon++ )
 		{
-			if ( longitudes[lon] < gridMinLon_) 
+			if ( longitudes[lon] < gridMinLon_)
 				continue;
-			if ( longitudes[lon] > gridMaxLon_) 
+			if ( longitudes[lon] > gridMaxLon_)
 				continue;
 			UserPoint point(longitudes[lon],lat);
 			PaperPoint xy = (*this)(point);
@@ -947,13 +1032,13 @@ void Proj4Projection::reprojectComponents(double& x, double& y, pair<double, dou
 	components.second = speed * sin(rotation);
 }
 
-void myprint(double x, double y, bool next = false) 
+void myprint(double x, double y, bool next = false)
 {
-	
+
 	MagLog::dev() << "[" << x << ", " << y << "]";
 	if ( next )
 		MagLog::dev() << "--->";
-	else 
+	else
 		MagLog::dev() << endl;
 }
 
@@ -967,11 +1052,11 @@ void Proj4Projection::reprojectSpeedDirection(const PaperPoint& point, pair<doub
 
 	fast_reproject(x, y);
 	fast_reproject(u, v);
-	
+
 	double rotation = atan2((u - x), (v - y));
-	
+
 	wind.second =   (rotation*RAD_TO_DEG);
-	
+
 }
 
 void Proj4Projection::revert(const vector< std::pair<double, double> > & in, vector< std::pair<double, double> > & out) const
@@ -1011,18 +1096,26 @@ void Proj4Projection::coastSetting(map<string, string>& setting, double abswidth
 	//const double yratio = ( ypcmax_ - ypcmin_ ) / absheight;
 
 	// choose the smallest (smaller ratio means more detail required)
-	const double ratio = 10;
+	const double area = ( max_pcx_-min_pcx_ ) * ( max_pcy_- min_pcy_);
 
+    double ratio = area/(abswidth*absheight);
+	
+    //projFACTORS data = proj_factors(to_, xy);
+
+
+	//cout << "RATIO" << area << endl;
+
+	
 	std::string resol = "110m";
-	if ( ratio < 100000 )  // highest resolution
+	if ( ratio < 1000000 )  // highest resolution
 	{
 		resol = "10m";
 	}
-	else if ( ratio < 300000)   // medium resolution
+	else if ( ratio < 3000000)   // medium resolution
 	{
 		resol = "50m";
 	}
-	resol = "110m";
+	
 	setting["resolution"]      = resol;
 	setting["land"]       = resol + "/ne_" + resol + "_land";
 	setting["ocean"]      = resol + "/ne_" + resol + "_ocean";
@@ -1034,8 +1127,8 @@ void Proj4Projection::coastSetting(map<string, string>& setting, double abswidth
 	MagLog::dev() << "GeoRectangularProjection::coastSetting[" << abswidth << ", " << absheight << "]->" <<  ratio << " resol: "<<resol<< endl;
 }
 
-void Proj4Projection::visit(MetaDataVisitor& visitor, 
-	double left, double top, 
+void Proj4Projection::visit(MetaDataVisitor& visitor,
+	double left, double top,
 	double width, double height,
 	double iwidth, double iheight)
 {
@@ -1081,8 +1174,12 @@ bool Proj4Projection::fast_reproject(double& x, double& y) const
 
 	if ( error  ) {
 
-			  MagLog::warning()  << pj_strerrno(error) << " for " << x << " " << y << endl;		
+
+
+			  //MagLog::warning()  << pj_strerrno(error) << " for " << x << " " << y << endl;		
 			  return false;	  
+
+
 	}
 	return true;
 }
@@ -1122,12 +1219,12 @@ void Proj4Projection::getNewDefinition(const UserPoint& ll, const UserPoint& ur,
 void Proj4Projection::setDefinition(const string& json)
 {
 	if (json.empty())
-				return;
+		return;
 
-			MagJSon helper;
-			helper.interpret(json);
+	MagJSon helper;
+	helper.interpret(json);
 
-			XmlNode node = **helper.tree_.firstElement();
-			node.name("");
-			set(node);
+	XmlNode node = **helper.tree_.firstElement();
+	node.name("");
+	set(node);
 }
