@@ -1,22 +1,12 @@
-/******************************** LICENSE ********************************
-
-
- Copyright 2007 European Centre for Medium-Range Weather Forecasts (ECMWF)
- 
- Licensed under the Apache License, Version 2.0 (the "License"); 
- you may not use this file except in compliance with the License. 
- You may obtain a copy of the License at 
- 
- 	http://www.apache.org/licenses/LICENSE-2.0
- 
- Unless required by applicable law or agreed to in writing, software 
- distributed under the License is distributed on an "AS IS" BASIS, 
- WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied. 
- See the License for the specific language governing permissions and 
- limitations under the License.
-
-
- ******************************** LICENSE ********************************/
+/*
+ * (C) Copyright 1996-2016 ECMWF.
+ * 
+ * This software is licensed under the terms of the Apache Licence Version 2.0
+ * which can be obtained at http://www.apache.org/licenses/LICENSE-2.0. 
+ * In applying this licence, ECMWF does not waive the privileges and immunities 
+ * granted to it by virtue of its status as an intergovernmental organisation nor
+ * does it submit to any jurisdiction.
+ */
 
 /*!
     \file Proj4Projection.h
@@ -209,12 +199,16 @@ public:
 	void conic();
 	void geos();
 	void simple();
+	void projectionSimple();
+	
 	void add(double, double);
+
 	double patchDistance(double) const;
 	const string& name() const { return definition_; }
 	void getNewDefinition(const UserPoint&, const UserPoint&, string&) const;
 	void setDefinition(const string&);
 	void reprojectComponents(double&, double&, pair<double, double>&) const;
+	void reprojectSpeedDirection(const PaperPoint& point, pair<double, double>&) const;
 	virtual void geoProjection(int& geo) const { geo = 1; } // Useful for Streamlines !
 protected:
      //! Method to print string about this class on to a stream of type ostream (virtual).
@@ -234,10 +228,10 @@ protected:
 	 double max_pcy_;
 	 mutable Epsg*   projection_;
 	 string definition_;
-	 double gridMinLon_;
-	 double gridMinLat_;
-	 double gridMaxLon_;
-	 double gridMaxLat_;
+	 mutable double gridMinLon_;
+	 mutable double gridMinLat_;
+	 mutable double gridMaxLon_;
+	 mutable double gridMaxLat_;
 
 
 private:
@@ -269,11 +263,21 @@ class Proj4EPSG3857 : public Proj4Projection
 public:
 	Proj4EPSG3857() : Proj4Projection("EPSG:3857") {}
 };
+class Proj4EPSG900913 : public Proj4Projection
+{
+public:
+    Proj4EPSG900913() : Proj4Projection("EPSG:3857") {}
+};
 class Proj4Geos : public Proj4Projection
 {
 public:
 	Proj4Geos() : Proj4Projection("geos") {}
 };
+class Proj4TPers : public Proj4Projection
+{
+public:
+	Proj4TPers() : Proj4Projection("tpers") {}
+};
 class Proj4Meteosat0 : public Proj4Projection
 {
 public:
@@ -349,7 +353,7 @@ public:
 class Proj4EPSG32661 : public Proj4Projection
 {
 public:
-	Proj4EPSG32661() : Proj4Projection(" EPSG:32661") {}
+	Proj4EPSG32661() : Proj4Projection("EPSG:32661") {}
 };
 class Proj4EPSG4326 : public Proj4Projection
 {
