@@ -90,7 +90,7 @@ void GribDecoder::set(const GribLoop& loop, int index)
     index_           = loop.uniqueId_;
     interpolation_method_ = loop.interpolation_method_;
     missing_fill_count_ = loop.missing_fill_count_;
-    wind_mode_       = auto_ptr<WindMode>(loop.wind_mode_->clone());
+    wind_mode_       = unique_ptr<WindMode>(loop.wind_mode_->clone());
     internalIndex_ = index;
 }
 
@@ -151,6 +151,7 @@ string GribDecoder::getstring(const string& key, bool warnIfKeyAbsent, bool cach
     }
     char val[1024];
     size_t length = 1024;
+    
 
     int err = grib_get_string(handle_, key.c_str(), val, &length);
 
@@ -158,12 +159,15 @@ string GribDecoder::getstring(const string& key, bool warnIfKeyAbsent, bool cach
     {
         if (warnIfKeyAbsent)
         {
+            
             MagLog::warning() << "Grib API: can not find key [" << key << "]  - "<< grib_get_error_message(err) <<"\n";
+             
         }
         return "";
     }
     if ( cache )
         sKeys_.insert(make_pair(key, val));
+    
     return string(val);
 }
 
@@ -300,8 +304,7 @@ void GribDecoder::read(Matrix **matrix, const Transformation&  transformation)
         *matrix = 0;
         return;
     }
-    long repres;
-    grib_get_long(handle_,"dataRepresentationType",&repres);
+    
     const string representation = getString("typeOfGrid");
 
     try {
@@ -1234,7 +1237,7 @@ public:
             string readAsLong = node.getAttribute("readAsLong");
             if(readAsLong != "yes")
             {
-                val =  grib_.getString(def);
+                val =  grib_.getString(def, false);
                 string format = node.getAttribute("format");
                 if ( !format.empty() ) {
                     char tmp[256];
@@ -1491,6 +1494,14 @@ const LevelDescription& GribDecoder::level()
     return dataLevel_;
 }
 
+void GribDecoder::ask(MetaDataCollector& meta)
+{
+    for ( auto m = meta.begin(); m != meta.end(); ++m) {
+        m->second = getString(m->first, false);
+        //cout << m->first << " = " << m->second << endl;
+    }
+}
+
 void GribDecoder::visit(MetaDataVisitor& meta)
 {
     if ( !handle_ )
@@ -1593,7 +1604,7 @@ void GribDecoder::visit(MetaDataCollector& step)
                     string representation = getString("typeOfGrid");
                     try
                     {
-                        auto_ptr<GribInterpretor> interpretor_(SimpleObjectMaker<GribInterpretor>::create(representation));
+                        unique_ptr<GribInterpretor> interpretor_(SimpleObjectMaker<GribInterpretor>::create(representation));
                         interpretor_->scaling(*this, scaling, offset,oriUnits,derivedUnits);
                         if(scaling==1 && offset == 0)
                         {
@@ -1658,6 +1669,7 @@ void GribDecoder::visit(MetaDataCollector& step)
             if(information_.find(key->first) != information_.end())
             {
                 key->second=information_[key->first];
+                //cout << "GRIB " << key->first << " = " << key->second << endl;
             }
         }
 
@@ -1763,14 +1775,25 @@ void GribDecoder::decode(const Transformation& transformation)
     to_ =  DateTime(helper.get("grib"+id_, "end-date"));
 }
 
+//// RV MF ////
+void GribDecoder::decode1D()
+{
+    if (matrix_) return;
+    field_ = open(field_);
+    read(&matrix_);
+}
+//// RV MF ////
+
 void GribDecoder::decode()
 {
 
     if ( dimension_ == 1) {
-        if (matrix_) return;
-        field_ = open(field_);
-        read(&matrix_);
-        if (!matrix_) return;
+// RV MF
+//      if (matrix_) return;
+//      field_ = open(field_);
+//      read(&matrix_);
+//      if (!matrix_) return;
+        decode1D();
     }
     else {
         decode2D();
@@ -2126,14 +2149,25 @@ public:
     {
 
         ostringstream out;
-        long istep = grib.getLong("startStep");
+        long startstep = grib.getLong("startStep"); 
+        long endstep = grib.getLong("endStep");
 
+        
+
+        if ( startstep != endstep ) {
+            ostringstream step;
+            step << "from t+" << startstep << " to t+" << endstep;
+            title.back() += step.str();
+            return;
+        }
+         
 
         ostringstream step;
-        step << istep;
+        step << startstep;
         string format = field.attribute("format", "t+%s");
         out << SimpleStringFormat(step.str(), format);
         title.back() += out.str();
+        
     }
 };
 
@@ -2301,6 +2335,7 @@ public:
             names[54] = "METEOSAT-7";
             names[55] = "METEOSAT-8";
             names[57] = "METEOSAT-10";
+            names[70] = "METEOSAT-11";
             names[172] = "MTSAT-2";
             names[257] = "GOES-13";
             names[259] = "GOES-15";
@@ -2348,6 +2383,15 @@ public:
             l57[9] = "IR 10-8";
             l57[10] = "IR 12-0";
             channels[57] = l57;
+            map<long, string>  l70;
+            l70[1] = "VIS 0-6";
+            l70[4] = "IR 3-9";
+            l70[5] = "WV 6-2";
+            l70[6] = "WV 7-3";
+            l70[8] = "IR 9-7";
+            l70[9] = "IR 10-8";
+            l70[10] = "IR 12-0";
+            channels[70] = l70;
             map<long, string>  l172;
             l172[2] = "IR 10-8";
             l172[4] = "WV 6-8";
